pub enum Continue {
SlowDown,
AuthorizationPending,
}Expand description
Control flow when polling the device flow authorization.
Variants
SlowDown
When you receive the slow_down error, 5 extra seconds are added to the minimum interval or timeframe required between your requests using POST https://github.com/login/oauth/access_token. For example, if the starting interval required at least 5 seconds between requests and you get a slow_down error response, you must now wait a minimum of 10 seconds before making a new request for an OAuth access token. The error response includes the new interval that you must use.
AuthorizationPending
This error occurs when the authorization request is pending and the user hasn’t entered the user code yet. The app is expected to keep polling the POST https://github.com/login/oauth/access_token request without exceeding the interval, which requires a minimum number of seconds between each request.