pub enum GraphqlResponse<T> {
Err(GraphqlErrorResponse<T>),
Ok(GraphqlOkResponse<T>),
}Expand description
GraphQL Response.
GraphQL can return a response with data or errors, or both in the case of a partial success.
Variants
Err(GraphqlErrorResponse<T>)
A response containing errors.
Ok(GraphqlOkResponse<T>)
A response representing a complete success with no errors.